---
name: Bug Report
about: Report a bug
labels:
  - bug
---

<!--
Thank you very much for filing a bug report!
We, the maintainers, are happy to help you. When opening an issue, please provide the following information to us.

If your issue is more a question on how o use tsfresh for your use-case, please have a look into
the Q&A: https://github.com/blue-yonder/tsfresh/discussions/categories/q-a
-->

**The problem**:

<!-- Please shortly describe your problem.

We recommend to include a self-contained copy-pastable example that generates the issue if possible.
If you need data to showcase your problem, please include a very small test dataset.

If you need some help on how to create good bug reports, have a look into those resources:

- Craft Minimal Bug Reports http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports
- Minimal Complete Verifiable Examples https://stackoverflow.com/help/mcve

Please include proper formatting of your error messages and code examples
using the formatting options and have a look into the "Preview" before sending your
bug report.

That makes diagnosing your issue much easier.
-->

**Anything else we need to know?**:

**Environment**:

- Python version:
- Operating System:
- tsfresh version:
- Install method (conda, pip, source):
